pub enum Address {
Account(AccountHash),
Contract(ContractPackageHash),
}Expand description
An enum representing an AccountHash or a ContractPackageHash.
Variants
Account(AccountHash)
Represents an account hash.
Contract(ContractPackageHash)
Represents a contract package hash.
Implementations
Sourceimpl CasperAddress
impl CasperAddress
Sourcepub fn as_account_hash(&self) -> Option<&AccountHash>
pub fn as_account_hash(&self) -> Option<&AccountHash>
Returns the inner account hash if self is the Account variant.
Sourcepub fn as_contract_package_hash(&self) -> Option<&ContractPackageHash>
pub fn as_contract_package_hash(&self) -> Option<&ContractPackageHash>
Returns the inner contract hash if self is the Contract variant.